#[non_exhaustive]pub enum EntryBuilderError {
MissingSpec,
MissingFile,
MissingFsType,
}Expand description
Error building an Entry via the builder pattern.
Returned by EntryBuilder::build
when a required field is missing.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingSpec
The spec field was not set before calling build().
MissingFile
The file (mount point) field was not set before calling build().
MissingFsType
The vfstype field was not set before calling build().