pub struct OptItem { /* private fields */ }Expand description
A single mount option item, consisting of a name and an optional value.
Examples
let item = OptItem::flag("ro").unwrap();
assert_eq!(item.name(), "ro");
assert!(item.value().is_none());
let item = OptItem::new("size", Some("10G".into())).unwrap();
assert_eq!(item.value(), Some("10G"));Implementations
Sourceimpl OptItem
impl OptItem
Sourcepub fn new(
name: impl Into<String>,
value: Option<String>,
) -> Result<Self, OptItemError>
pub fn new( name: impl Into<String>, value: Option<String>, ) -> Result<Self, OptItemError>
Create a new option item with an optional value.
Errors
Returns OptItemError::EmptyName if the name is empty.
Sourcepub fn class(&self) -> Option<OptionClass>
pub fn class(&self) -> Option<OptionClass>
The classification of this option (VFS, filesystem, or userspace).
Returns None for unknown options.