Error types for all fstab parsing and validation operations.
This module defines the error hierarchy used throughout the library.
Each error type implements std::error::Error via thiserror.
Enums
- Entry
Builder Error - Error building an
Entryvia the builder pattern. - FsType
Error - Error parsing a filesystem type (fstab field 3).
- Fstab
Error - Fstab parsing and editing error.
- Mount
Point Error - Error constructing a
MountPoint. - OptItem
Error - Error constructing an
OptItem. - Options
Error - Error parsing mount options (fstab field 4).
- Parse
Error Kind - Specific kind of parse error on a single fstab line.
- Spec
Error - Error parsing a spec (fstab field 1).